/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dusk.h"

typedef enum {
  FACING_DIRECTION_SOUTH,
  FACING_DIRECTION_EAST,
  FACING_DIRECTION_NORTH,
  FACING_DIRECTION_WEST
} facingdir_t;

#define FACING_DIRECTION_COUNT 4

/**
 * Converts a facing direction to a directional vector.
 * 
 * @param dir The direction to convert.
 * @param x The x component of the vector.
 * @param y The y component of the vector.
 */
void facingDirGetRelative(const facingdir_t dir, int8_t *x, int8_t *y);

/**
 * Adds a facing direction to a position.
 * 
 * @param dir The direction to add.
 * @param x The x position to add to.
 * @param y The y position to add to.
 */
void facingDirAdd(const facingdir_t dir, uint8_t *x, uint8_t *y);