// Copyright (c) 2025 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "../../../../dusk/display/tilesetdefs.h"

struct Tileset {
  int columns;
  int rows;
  int width;
  int height;
};

layout(std140) uniform b_Tilesets {
  Tileset tilesets[TILESET_SLOT_COUNT];
};

uniform sampler2D u_TilesetTextures[TILESET_SLOT_COUNT];

vec4 tilesetGetUVs(int tilesetIndex, int col, int row) {
  Tileset tileset = tilesets[tilesetIndex];
  float segWidth = 1.0 / float(tileset.columns);
  float segHeight = 1.0 / float(tileset.rows);
  float x = float(col) * segWidth;
  float y = float(row) * segHeight;
  return vec4(x, y, x + segWidth, y + segHeight);
}

vec4 tilesetGetUVsByIndex(int tilesetIndex, int index) {
  Tileset tileset = tilesets[tilesetIndex];
  int col = index % tileset.columns;
  int row = index / tileset.columns;
  return tilesetGetUVs(tilesetIndex, col, row);
}

vec4 tilesetGetColor(int tilesetIndex, vec2 coord) {
  switch(tilesetIndex) {
    case 0:
      return texture(u_TilesetTextures[0], coord);
    case 1:
      return texture(u_TilesetTextures[1], coord);
    case 2:
      return texture(u_TilesetTextures[2], coord);
    case 3:
      return texture(u_TilesetTextures[3], coord);
    default:
      return vec4(1, 1, 1, 1);
  }
}